@@ -40,11 +40,6 @@ package java.security.cert;
 
 import java.math.BigInteger;
 import java.security.Principal;
-import java.security.PublicKey;
-import java.security.NoSuchAlgorithmException;
-import java.security.InvalidKeyException;
-import java.security.NoSuchProviderException;
-import java.security.SignatureException;
 import java.util.Date;
 
 /**
